@@ -2,6 +2,15 @@
 更新内容一览
 """
 
+"""
+2022/5/23
+control_version:0.6.1
+blcoklyFile_version:2.2.6
+blockly_version:2.2.2
+修改一个视觉bug
+
+"""
+
 """
 2022/5/23
 control_version:0.6.0
