@@ -1,5 +1,4 @@
-import re
-
+import websocket,json,threading,os,pyaudio,subprocess,time,re
 
 #用来转换数字
 class Number_Convert():
@@ -10,10 +9,9 @@ class Number_Convert():
         self.unit_map = {'十': 10, '百': 100, '千': 1000, '万': 10000, '亿': 100000000}  # 数字单位
 
 
-    def __operate(self, num_str):  # 这个和下面呢个____operate1都是处理字符串的函数，别调用
+    def __operate(self, num_str:str):  # 这个和下面呢个____operate1都是处理字符串的函数，别调用
         Num = 0
         unit = False
-        print(num_str)
         for index, i in enumerate(num_str[::-1]):
             if i in self.number_map.keys():
                 Num += self.number_map[i] * (unit if unit else 1)
@@ -23,7 +21,7 @@ class Number_Convert():
                 Num += self.unit_map[i]
         return Num
 
-    def __operate1(self, strings):  # 处理字符串的，分成了三种情况，有“亿”，无“亿”有“万”， 无“亿”无“万”
+    def __operate1(self, strings:str):  # 处理字符串的，分成了三种情况，有“亿”，无“亿”有“万”， 无“亿”无“万”
 
         if '亿' in strings:
             strings2 = strings.split('亿')
@@ -46,7 +44,7 @@ class Number_Convert():
         else:
             return self.__operate(strings)
 
-    def num_convert3(self, test_strings):
+    def num_convert3(self, test_strings:str):
         self.NumList = [] #装数字的列表
         self.converted_strings = ''  # 转化后的字符串
         self.test_strings = test_strings.replace("什","【·&……】")
@@ -71,6 +69,117 @@ class Number_Convert():
             self.NumList.append((int(num.group()), num.span()[0]))
         return [self.converted_strings.replace("【·&……】","什"), sorted(self.NumList, key=lambda x: x[1])]
 
+######################本地化语音########################
+
+class Yuyin_local():
+    def __init__(self,record_time_s,local_yuyinPath,asyn=True,filename=''):
+        os.system("chcp 65001") #切换语音为Unicode (UTF-8)
+        vbsPath = os.path.join(local_yuyinPath,"runbat.vbs")
+        subprocess.call(f"cscript  {vbsPath}", stdout=None, stdin=None)
+        self.ws_app = websocket.WebSocketApp("ws://127.0.0.1:10086",
+                                        on_open=lambda ws: self.on_open(ws, record_time_s),  # 连接建立后的回调
+                                        on_message=self.on_message,  # 接收消息的回调
+                                        )
+        self.total_sentance = '' #存放语音识别的内容
+        self.asyn = asyn
+        self.filename = filename
+        p = pyaudio.PyAudio()
+        self.stream = p.open(format=pyaudio.paInt16,
+                        channels= 1,
+                        rate=16000,
+                        input=True,
+                        frames_per_buffer=1024,
+                        )
+
+    def run(self):
+        self.ws_app.run_forever()
+
+
+
+    def on_message(self,ws, message):
+        """
+        接收服务端返回的消息
+        :param ws:
+        :param message: json格式，自行解析
+        :return:
+        """
+
+        self.Dict = json.loads(message)
+        #如果判断一段话结束了，就把这段话存储到self.total_sentance里面，下一段话就可以在这一段话之后继续拼接
+        if self.Dict['type']=="final_result"  and self.asyn:
+            self.total_sentance += json.loads(self.Dict['nbest'])[0]['sentence']
+        #server_ready是我们发送开始帧的时候传回来的数据，我们不需要读取
+        if self.Dict['type'] != "server_ready" and self.asyn:
+            print('\r',self.total_sentance+json.loads(self.Dict['nbest'])[0]['sentence'],end='', flush=True)
+
+    def on_open(self,ws, record_time_s):
+        """
+        连接后发送数据帧
+        :param  websocket.WebSocket ws:
+        :return:
+        """
+
+        def run(*args):
+            """
+            主程序
+            :param args:
+            :return:
+            """
+            '''
+             发送二进制音频数据，注意每个帧之间需要有间隔时间
+             :param ws:
+             :param record_time_s: 录音时长，单位是秒
+             :return:
+             '''
+            # 开始参数帧,写死的，不要动
+            startData = '{"signal":"start","nbest":1,"continuous_decoding":true}'
+            ws.send(startData, websocket.ABNF.OPCODE_TEXT)
+            if self.asyn: #一边说一边识别
+                print(f'开始录音，持续{record_time_s}秒')
+                for i in range(0, int(16000 / 1024) * record_time_s):
+                    data = self.stream.read(1024)
+                    ws.send(data, websocket.ABNF.OPCODE_BINARY)
+                print('\n录音结束')
+            else:
+                chunk_ms = 160  # 160ms的录音
+                chunk_len = int(16000 * 2 / 1000 * chunk_ms)
+                with open(self.filename, 'rb') as f:
+                    pcm = f.read()
+                index = 0
+                total = len(pcm)
+                print("开始识别")
+                total_time_s = time.time()+total/32000
+                while index < total:
+                    end = index + chunk_len
+                    if end >= total:
+                        # 最后一个音频数据帧
+                        end = total
+                    body = pcm[index:end]
+                    ws.send(body, websocket.ABNF.OPCODE_BINARY)
+                    index = end
+                    time.sleep(chunk_ms / 1000.0)  # ws.send 也有点耗时，这里没有计算
+                    last_time = round(total_time_s-time.time(),1)
+                    print('\r',"识别中，预计还差",last_time if last_time>0 else 0.00,"秒",end='',flush=True)
+            print("\n识别结束")
+            #避免时间过短导致句子还没结束，函数就结束了
+            if self.Dict:
+                if self.Dict["type"] == "partial_result":
+                    self.total_sentance += json.loads(self.Dict['nbest'])[0]['sentence']
+            # 发送结束帧，写死的，不要动
+            endData = '{ signal: "end" }'
+            ws.send(endData, websocket.ABNF.OPCODE_TEXT)
+            self.ws_app.close()
+
+        threading.Thread(target=run).start()
+
+
+
+
+
+
+
+
+
 ######################以下是playsound修改版本###################
 import logging
 
